@@ -7,11 +7,11 @@ def test_urls(files):
     headers = {'User-Agent': 'Mozilla/5.0 (compatible; MSIE 6.0; Fiona CI check)'}
 
     for fpath in files:
-        print("Processing: {}".format(fpath))
+        print(f"Processing: {fpath}")
         with open(fpath) as f:
 
             text = f.read()
-            urls = re.findall('(https?:\/\/[^\s`>\'"()]+)', text)
+            urls = re.findall('(https?:\\/\\/[^\\s`>\'"()]+)', text)
 
             for url in urls:
                 http_code = None
