@@ -1,10 +1,8 @@
 """Tests of _env util module"""
 
+from unittest import mock
+
 import pytest
-try:
-    from unittest import mock
-except ImportError:
-    import mock
 
 from fiona._env import GDALDataFinder, PROJDataFinder
 
@@ -33,13 +31,8 @@ def mock_fhs(tmpdir):
 @pytest.fixture
 def mock_debian(tmpdir):
     """A fake Debian multi-install system"""
-    tmpdir.ensure("share/gdal/1.11/header.dxf")
-    tmpdir.ensure("share/gdal/2.0/header.dxf")
-    tmpdir.ensure("share/gdal/2.1/header.dxf")
-    tmpdir.ensure("share/gdal/2.2/header.dxf")
-    tmpdir.ensure("share/gdal/2.3/header.dxf")
-    tmpdir.ensure("share/gdal/2.4/header.dxf")
-    tmpdir.ensure("share/gdal/3.0/header.dxf")
+    tmpdir.ensure("share/gdal/{}.{}/header.dxf".format(gdal_version.major,
+                                                       gdal_version.minor))
     tmpdir.ensure("share/proj/epsg")
     return tmpdir
 
@@ -77,7 +70,7 @@ def test_search_debian_gdal_data_failure(tmpdir):
 def test_search_debian_gdal_data(mock_debian):
     """Find GDAL data under Debian locations"""
     finder = GDALDataFinder()
-    assert finder.search_debian(str(mock_debian)) == str(mock_debian.join("share").join("gdal").join("{}.{}".format(gdal_version.major, gdal_version.minor)))
+    assert finder.search_debian(str(mock_debian)) == str(mock_debian.join("share").join("gdal").join(f"{gdal_version.major}.{gdal_version.minor}"))
 
 
 def test_search_gdal_data_wheel(mock_wheel):
@@ -93,7 +86,7 @@ def test_search_gdal_data_fhs(mock_fhs):
 def test_search_gdal_data_debian(mock_debian):
     """Find GDAL data under Debian locations"""
     finder = GDALDataFinder()
-    assert finder.search(str(mock_debian)) == str(mock_debian.join("share").join("gdal").join("{}.{}".format(gdal_version.major, gdal_version.minor)))
+    assert finder.search(str(mock_debian)) == str(mock_debian.join("share").join("gdal").join(f"{gdal_version.major}.{gdal_version.minor}"))
 
 
 def test_search_wheel_proj_data_failure(tmpdir):
