@@ -1,7 +1,6 @@
 """Test listing a datasource's layers."""
 
-import logging
-import sys
+from pathlib import Path
 import os
 
 import pytest
@@ -32,11 +31,11 @@ def test_directory_trailing_slash(data_dir):
 
 def test_zip_path(path_coutwildrnp_zip):
     assert fiona.listlayers(
-        'zip://{}'.format(path_coutwildrnp_zip)) == ['coutwildrnp']
+        f'zip://{path_coutwildrnp_zip}') == ['coutwildrnp']
 
 
 def test_zip_path_arch(path_coutwildrnp_zip):
-    vfs = 'zip://{}'.format(path_coutwildrnp_zip)
+    vfs = f'zip://{path_coutwildrnp_zip}'
     with pytest.warns(FionaDeprecationWarning):
         assert fiona.listlayers('/coutwildrnp.shp', vfs=vfs) == ['coutwildrnp']
 
@@ -63,6 +62,11 @@ def test_invalid_path_ioerror():
         fiona.listlayers("foobar")
 
 
+def test_path_object(path_coutwildrnp_shp):
+    path_obj = Path(path_coutwildrnp_shp)
+    assert fiona.listlayers(path_obj) == ['coutwildrnp']
+
+
 def test_listing_file(path_coutwildrnp_json):
     """list layers from an open file object"""
     with open(path_coutwildrnp_json, "rb") as f:
@@ -77,7 +81,12 @@ def test_listing_pathobj(path_coutwildrnp_json):
 
 def test_listdir_path(path_coutwildrnp_zip):
     """List directories in a path"""
-    assert fiona.listdir('zip://{}'.format(path_coutwildrnp_zip)) == ['coutwildrnp.shp', 'coutwildrnp.shx', 'coutwildrnp.dbf', 'coutwildrnp.prj']
+    assert sorted(fiona.listdir("zip://{}".format(path_coutwildrnp_zip))) == [
+        "coutwildrnp.dbf",
+        "coutwildrnp.prj",
+        "coutwildrnp.shp",
+        "coutwildrnp.shx",
+    ]
 
 
 def test_listdir_path_not_existing(data_dir):
@@ -93,25 +102,19 @@ def test_listdir_invalid_path():
         assert fiona.listdir(1)
 
 
-def test_listdir_file(path_coutwildrnp_zip):
-    """ Test list directories of a file"""
-    with pytest.raises(FionaValueError):
-        fiona.listdir('zip://{}/coutwildrnp.shp'.format(path_coutwildrnp_zip))
-
-
 def test_listdir_file(path_coutwildrnp_zip):
     """Test list directories of a file"""
     with pytest.raises(FionaValueError):
-        fiona.listdir("zip://{}/coutwildrnp.shp".format(path_coutwildrnp_zip))
+        fiona.listdir(f"zip://{path_coutwildrnp_zip}/coutwildrnp.shp")
 
 
 def test_listdir_zipmemoryfile(bytes_coutwildrnp_zip):
     """Test list directories of a zipped memory file."""
     with ZipMemoryFile(bytes_coutwildrnp_zip) as memfile:
         print(memfile.name)
-        assert fiona.listdir(memfile.name) == [
-            "coutwildrnp.shp",
-            "coutwildrnp.shx",
+        assert sorted(fiona.listdir(memfile.name)) == [
             "coutwildrnp.dbf",
             "coutwildrnp.prj",
+            "coutwildrnp.shp",
+            "coutwildrnp.shx",
         ]
